@@ -19,7 +19,7 @@ use Lingua::PTD::BzDmp;
 use Lingua::PTD::XzDmp;
 use Lingua::PTD::SQLite;
 
-our $VERSION = '1.04_02';
+our $VERSION = '1.04_03';
 
 =encoding UTF-8
 
@@ -706,6 +706,10 @@ sensitive alignment.
 sub lowercase {
     my ($self, %ops) = @_;
 
+    print STDERR "\n\n";
+    print STDERR "--> ", join(" ", ord("ç"), ord(lc "Ç"), ord("ã"), ord(lc "Ã"));
+    print STDERR "\n\n";
+
     $ops{verbose} //= $self->verbose;
 
     $self->downtr(
